/*-------------------------------------------------------------------------
 * Copyright (c) 2000-2007 Kenneth W. Sodemann (ken.sodemann@gmail.com)
 * Copyright (c) 2014, Alex Panin (alex@linuxonly.ru) and Alexey Loginov (loginov.alex.valer@gmail.com)
 *-------------------------------------------------------------------------
 * about_dlg
 *
 * Synopsis:
 *   MathWars obligatory about dialog
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to
 * Free Software Foundation, Inc.
 * 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 *-------------------------------------------------------------------------
 */
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <gtk/gtk.h>
#include <glib/gi18n.h>

#define MSG _("A simple, but fun, math game for grade school aged kids.  \
Based loosely on the popular 'War' card game.")

static void
about_on_response(GtkDialog *dialog, gint response_id, gpointer user_data)
{
	gtk_widget_hide(GTK_WIDGET(dialog));
}

static GtkWidget *
create_about_dlg (GtkWidget *parent)
{
   GtkWidget *about_dlg;
   gchar *logo_str;
   GdkPixbuf *logo_img;
   const gchar *authors[] = {
      "Ken Sodemann <ken.sodemann@gmail.com>",
      "Alex Panin <alex@linuxonly.ru>",
      "Alexey Loginov <loginov.alex.valer@gmail.com>",
      NULL
   };
   
   const gchar *licence = 
       _("MathWar is free software; you can redistribute it and/or modify \n"
         "it under the terms of the GNU General Public License as published by \n"
         "the Free Software Foundation; either version 2 of the License, or \n"
         "(at your option) any later version.\n"
         "MathWar is distributed in the hope that it will be useful, \n"
         "but WITHOUT ANY WARRANTY; without even the implied warranty of \n"
         "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the \n"
         "GNU General Public License for more details.\n"
         "You should have received a copy of the GNU General Public License \n"
         "along with MathWar; if not, write to the Free Software Foundation, Inc., \n"
         "51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA");
   
   about_dlg = gtk_about_dialog_new();
   gtk_about_dialog_set_program_name(GTK_ABOUT_DIALOG(about_dlg), PACKAGE);
   gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(about_dlg), VERSION);
   gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(about_dlg), MSG);
   gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(about_dlg), _("Copyright (c) 2000-2007 Kenneth W. Sodemann,\nCopyright (c) 2014 Alex Panin and Alexey Loginov"));
   gtk_about_dialog_set_license(GTK_ABOUT_DIALOG(about_dlg), licence);
   gtk_about_dialog_set_authors(GTK_ABOUT_DIALOG(about_dlg), authors);
   logo_str = g_build_filename(PACKAGE_DATA_DIR, "pixmaps", "mw_logo.png", NULL);
   logo_img = gdk_pixbuf_new_from_file(logo_str, NULL);
   if (logo_img != NULL) {
	   gtk_about_dialog_set_logo(GTK_ABOUT_DIALOG(about_dlg), logo_img);
	   g_object_unref(logo_img);
   }
   g_free(logo_str);
   
   if (parent != NULL) {
	   gtk_window_set_transient_for(GTK_WINDOW(about_dlg), GTK_WINDOW(parent));
   }
   
   g_signal_connect(about_dlg, "response", G_CALLBACK(about_on_response), about_dlg);
   g_signal_connect(about_dlg, "delete-event", G_CALLBACK(gtk_widget_hide_on_delete), NULL);
   
   gtk_widget_show_all(about_dlg);

   return about_dlg;
}

void
show_about_dlg (GtkWidget *parent)
{
   static GtkWidget *about_dlg = NULL;

   /*
    * If the dialog box exists, just make sure it is visable, otherwise
    * create it.
    */
   if (about_dlg != NULL) {
	  gtk_window_present(GTK_WINDOW(about_dlg));
   } else {
      about_dlg = create_about_dlg(parent);
   }
}
